@@ -151,7 +151,9 @@ main(int argc, char *argv[])
 
     device = argv[1];
 
-    daemon(0,0);
+    if (daemon(0,0))
+        exit(1);
+
     syslog (LOG_INFO, "starting, device = %s", argv[1]);
 
     loop = g_main_loop_new (NULL, FALSE);
